**Example 1: 烧录回执**



Input: 

```
tccli iottid BurnTidNotify --cli-unfold-argument  \
    --OrderId p8ZcXGuqus \
    --Tid 000001035D0C97E3D2A46283D27BC612
```

Output: 
```
{
    "Response": {
        "RequestId": "37ce9615-4038-4b62-a6dc-5aebe2c45380",
        "Tid": "000001035D0C97E3D2A46283D27BC612"
    }
}
```

